from rocolib.api.components.Component import Component

c = Component()

c.addSubcomponent("boat", "BoatBase", inherit=True, prefix=None)
c.addSubcomponent("lServoMount", "SideServoMount", inherit="depth")
c.addSubcomponent("rServoMount", "SideServoMount", inherit="depth")

#topDistance and botDistance (and servoMount length) determine the dimensions of the boat hull
c.addParameter("topDistance", 150, paramType="length", minValue=0) #servo mount length above the connecting edge
c.addParameter("botDistance", 100, paramType="length", minValue=73) #servo mount length below the connecting edge

c.addConstraint(("boat","boat.length"), ("topDistance", "botDistance", "lServoMount.depth"), "x[0] + x[1] + x[2]")

c.addSubcomponent("lsplit", "SplitEdge")
c.addConstraint(("lsplit", "toplength"), ("topDistance", "botDistance", "lServoMount.depth"), "(x[0] + x[1] + x[2],)")
c.addConstraint(("lsplit", "botlength"), ("topDistance", "botDistance", "lServoMount.depth"), "(x[0], x[2], x[1])") #but the value of the new component's boat.length parameter is completely disconnected from the value of the boat component's boat.length parameter
#
c.addSubcomponent("rsplit", "SplitEdge")
c.addConstraint(("rsplit", "toplength"), ("topDistance", "botDistance", "rServoMount.depth"), "(x[0] + x[1] + x[2],)")
c.addConstraint(("rsplit", "botlength"), ("topDistance", "botDistance", "rServoMount.depth"), "(x[1], x[2], x[0])") #but the value of the new component's boat.length parameter is completely disconnected from the value of the boat component's boat.length parameter

c.addConnection(("lsplit", "botedge1"), ("lServoMount", "rightInterface"), angle=180) #both face the same direction
c.addConnection(("rsplit", "botedge1"), ("rServoMount", "leftInterface"), angle=180)
#
c.addConnection(("boat", "portedge"), ("lsplit", "topedge0"))
c.addConnection(("boat", "staredge"), ("rsplit", "topedge0"))

c.inheritInterface("topPort", ("lsplit", "botedge0"))
c.inheritInterface("botPort", ("lsplit", "botedge2"))
c.inheritInterface("topStar", ("rsplit", "botedge2"))
c.inheritInterface("botStar", ("rsplit", "botedge0"))

c.toLibrary("BoatWithServoMount")
