from rocolib.api.components.Component import Component
from rocolib.api.Function import Function


c = Component()

c.addSubcomponent("stack", "SubESP32Stack", inherit=True)

c.addParameter("depth", 70, paramType="length") #must set to boat depth
c.addParameter("width", 70, paramType="length")#must set to boat width

c.addSubcomponent("topCover", "Rectangle")
c.addConstraint(("topCover", "w"), "stack.brains", "getDim(x, 'width')")
c.addConstraint(("topCover", "l"), "stack.length") #length is 61, from SubESP32Stack

c.addSubcomponent("botCover", "Rectangle")
c.addConstraint(("botCover", "w"), "stack.brains", "getDim(x, 'width')")
c.addConstraint(("botCover", "l"), "stack.length")

c.addConnection(("botCover", "l"), ("stack", "topedge0"), angle=90, tabWidth=10)
c.addConnection(("topCover", "r"), ("stack", "botedge0"), angle=90, tabWidth=7)

#c.addConnection(("botCover", "t"), ("stack", "botedge1"), angle=90, tabWidth=10)
c.addConnection(("topCover", "t"), ("stack", "topedge1"), angle=90)

c.addConnection(("botCover", "r"), ("stack", "topedge2"), angle=90, tabWidth=10)
c.addConnection(("topCover", "l"), ("stack", "botedge2"), angle=90, tabWidth=7)

#c.addConnection(("botCover", "b"), ("stack", "topedge3"), angle=90, tabWidth=10)
c.addConnection(("topCover", "b"), ("stack", "topedge3"), angle=90, tabWidth=7)

c.addSubcomponent("servoPins", "Cutout")
c.addConstConstraint(("servoPins", "dx"), 11)
c.addConstConstraint(("servoPins", "dy"), 13)
c.addConnection(("botCover", "face"),
                   ("servoPins", "decoration"),
                   mode="hole",offset=Function(params=("depth"), fnstring="(-7, 0)"))#offset=Function(params=("dy1"), fnstring="(10, 0)")

c.addSubcomponent("microUSB", "Cutout")
c.addConstConstraint(("microUSB", "dx"), 6)
c.addConstConstraint(("microUSB", "dy"), 10)
c.addConnection(("botCover", "face"),
                   ("microUSB", "decoration"),
                   mode="hole",offset=Function(params=("depth"), fnstring="(22, 0)"))#offset=Function(params=("dy1"), fnstring="(10, 0)")

c.addSubcomponent("lArm", "Rectangle", inherit=True)
c.addConstraint(("lArm", "w"), ("depth", "width", "stack.length"), "((0.5 * x[0]) ** 2 + (x[2] - x[1]) ** 2) ** 0.5") #c.addConstraint(("split0", "botlength"), "length", "(1/3*x-10, 10, 2/3*x)")
c.addConstraint(("lArm", "l"), "stack.length") #the support is as long as the boat is wide
c.addConnection(("lArm", "b"), ("botCover", "t"), angle=45)

c.addSubcomponent("rArm", "Rectangle", inherit=True)
c.addConstraint(("rArm", "w"), ("depth", "width", "stack.length"), "((0.5 * x[0]) ** 2 + (x[2] - x[1]) ** 2) ** 0.5")
c.addConstraint(("rArm", "l"), "stack.length") #the support is as long as the boat is wide
c.addConnection(("rArm", "b"), ("botCover", "b"), angle=45)

c.inheritInterface("leftArmInterface", ("lArm", "t"))
c.inheritInterface("rightArmInterface", ("rArm", "t"))

c.toLibrary("StackMount")
